pub struct Backend<Block: BlockT> { /* private fields */ }Expand description
Disk backend.
Disk backend keeps data in a key-value store. In archive mode, trie nodes are kept from all blocks. Otherwise, trie nodes are kept only from some recent blocks.
Implementations
Sourceimpl<Block: BlockT> Backend<Block>
impl<Block: BlockT> Backend<Block>
Sourcepub fn new(
db_config: DatabaseSettings,
canonicalization_delay: u64,
) -> ClientResult<Self>
pub fn new( db_config: DatabaseSettings, canonicalization_delay: u64, ) -> ClientResult<Self>
Create a new instance of database backend.
The pruning window is how old a block must be before the state is pruned.
Sourcepub fn reset_trie_cache(&self)
pub fn reset_trie_cache(&self)
Reset the shared trie cache.
Sourcepub fn new_test(blocks_pruning: u32, canonicalization_delay: u64) -> Self
pub fn new_test(blocks_pruning: u32, canonicalization_delay: u64) -> Self
Create new memory-backed client backend for tests.
Sourcepub fn new_test_with_pruning_filters(
blocks_pruning: u32,
canonicalization_delay: u64,
pruning_filters: Vec<Arc<dyn PruningFilter>>,
) -> Self
pub fn new_test_with_pruning_filters( blocks_pruning: u32, canonicalization_delay: u64, pruning_filters: Vec<Arc<dyn PruningFilter>>, ) -> Self
Create new memory-backed client backend for tests with custom pruning filters.
Sourcepub fn new_test_with_tx_storage(
blocks_pruning: BlocksPruning,
canonicalization_delay: u64,
) -> Self
pub fn new_test_with_tx_storage( blocks_pruning: BlocksPruning, canonicalization_delay: u64, ) -> Self
Create new memory-backed client backend for tests.
Sourcepub fn new_test_with_tx_storage_and_filters(
blocks_pruning: BlocksPruning,
canonicalization_delay: u64,
pruning_filters: Vec<Arc<dyn PruningFilter>>,
) -> Self
pub fn new_test_with_tx_storage_and_filters( blocks_pruning: BlocksPruning, canonicalization_delay: u64, pruning_filters: Vec<Arc<dyn PruningFilter>>, ) -> Self
Create new memory-backed client backend for tests with custom pruning filters.
Sourcepub fn new_test_with_tx_storage_source(
blocks_pruning: BlocksPruning,
canonicalization_delay: u64,
source: DatabaseSource,
pruning_filters: Vec<Arc<dyn PruningFilter>>,
) -> Self
pub fn new_test_with_tx_storage_source( blocks_pruning: BlocksPruning, canonicalization_delay: u64, source: DatabaseSource, pruning_filters: Vec<Arc<dyn PruningFilter>>, ) -> Self
Test backend with caller-chosen DatabaseSource (memdb / rocksdb / parity-db).
Sourcepub fn expose_db(&self) -> (Arc<dyn Database<DbHash>>, ColumnId)
pub fn expose_db(&self) -> (Arc<dyn Database<DbHash>>, ColumnId)
Expose the Database that is used by this backend. The second argument is the Column that stores the State.
Should only be needed for benchmarking.
Sourcepub fn expose_storage(&self) -> Arc<dyn Storage<HashingFor<Block>>>
pub fn expose_storage(&self) -> Arc<dyn Storage<HashingFor<Block>>>
Expose the Storage that is used by this backend.
Should only be needed for benchmarking.
Expose the shared trie cache that is used by this backend.
Should only be needed for benchmarking.